@@ -119,6 +119,9 @@ class RelList(object):
     def append(self, item):
         self._rels.append(item)
 
+    def extend(self, items):
+        self._rels.extend(items)
+
     def __iter__(self):
         return RelListIter(self)
 
@@ -225,23 +228,33 @@ class HALDoc(AttrDict):
                 else:
                     self.links[rel] = HALLink(link)
 
-    def create(self, resource, cache=True):
+    def create(self, resource, cache=True, auth=None):
         '''Assumes this resource is some kind of collection that can have new
         resources added to it. Attempts to post the given resource to this
         resource's 'createForm' link. You can override the HALDoc's cache
         setting when creating resources, such as in a data posting script'''
         create_url = self.links.createForm.href
+        # if auth info is given here, override self._auth
+        auth = auth or self._auth
         logger.debug("posting %s to %s" % (resource, create_url))
         response = _request_with_error('POST', create_url,
                                        data=json.dumps(resource),
-                                       auth=self._auth)
+                                       auth=auth).json()
 
-        resource = HALDoc(response.json())
-        if self._should_cache and cache and 'items' in self.rels:
-            # if this is a collection with an items rel then we can add the new
-            # item to it
-            self.rels['items'].append(resource)
-        return resource
+        if isinstance(response, list):
+            resources = [HALDoc(item) for item in response]
+            if self._should_cache and cache and 'items' in self.rels:
+                # if this is a collection with an items rel then we can add the
+                # new items to it
+                self.rels['items'].extend(resources)
+            return resources
+        else:
+            resource = HALDoc(response)
+            if self._should_cache and cache and 'items' in self.rels:
+                # if this is a collection with an items rel then we can add the
+                # new item to it
+                self.rels['items'].append(resource)
+            return resource
 
     def embed_resource(self, rel, resource):
         self.embedded[rel] = resource
